enum Foo {
    name__0,
    string__0
}
function foo() {
    enum Foo__2 {
        name__0,
        string__0
    }
    const foo__2 = {} as Foo__2;
}
const bar = {} as Foo;
